Crate sdl_image_sys

Crate sdl_image_sys 

Modules

constants
Generated constants

Structs

IMG_Animation
Animated image support
IMG_AnimationDecoder
IMG_AnimationDecoderStatus
An enum representing the status of an animation decoder.
IMG_AnimationEncoder

Constants

IMG_PROP_ANIMATION_DECODER_CREATE_AVIF_ALLOW_INCREMENTAL_BOOLEAN
IMG_PROP_ANIMATION_DECODER_CREATE_AVIF_ALLOW_PROGRESSIVE_BOOLEAN
IMG_PROP_ANIMATION_DECODER_CREATE_AVIF_MAX_THREADS_NUMBER
IMG_PROP_ANIMATION_DECODER_CREATE_FILENAME_STRING
IMG_PROP_ANIMATION_DECODER_CREATE_GIF_NUM_COLORS_NUMBER
IMG_PROP_ANIMATION_DECODER_CREATE_GIF_TRANSPARENT_COLOR_INDEX_NUMBER
IMG_PROP_ANIMATION_DECODER_CREATE_IOSTREAM_AUTOCLOSE_BOOLEAN
IMG_PROP_ANIMATION_DECODER_CREATE_IOSTREAM_POINTER
IMG_PROP_ANIMATION_DECODER_CREATE_TIMEBASE_DENOMINATOR_NUMBER
IMG_PROP_ANIMATION_DECODER_CREATE_TIMEBASE_NUMERATOR_NUMBER
IMG_PROP_ANIMATION_DECODER_CREATE_TYPE_STRING
IMG_PROP_ANIMATION_ENCODER_CREATE_AVIF_KEYFRAME_INTERVAL_NUMBER
IMG_PROP_ANIMATION_ENCODER_CREATE_AVIF_MAX_THREADS_NUMBER
IMG_PROP_ANIMATION_ENCODER_CREATE_FILENAME_STRING
IMG_PROP_ANIMATION_ENCODER_CREATE_GIF_USE_LUT_BOOLEAN
IMG_PROP_ANIMATION_ENCODER_CREATE_IOSTREAM_AUTOCLOSE_BOOLEAN
IMG_PROP_ANIMATION_ENCODER_CREATE_IOSTREAM_POINTER
IMG_PROP_ANIMATION_ENCODER_CREATE_QUALITY_NUMBER
IMG_PROP_ANIMATION_ENCODER_CREATE_TIMEBASE_DENOMINATOR_NUMBER
IMG_PROP_ANIMATION_ENCODER_CREATE_TIMEBASE_NUMERATOR_NUMBER
IMG_PROP_ANIMATION_ENCODER_CREATE_TYPE_STRING
IMG_PROP_METADATA_AUTHOR_STRING
IMG_PROP_METADATA_COPYRIGHT_STRING
IMG_PROP_METADATA_CREATION_TIME_STRING
IMG_PROP_METADATA_DESCRIPTION_STRING
IMG_PROP_METADATA_FRAME_COUNT_NUMBER
IMG_PROP_METADATA_IGNORE_PROPS_BOOLEAN
IMG_PROP_METADATA_LOOP_COUNT_NUMBER
IMG_PROP_METADATA_TITLE_STRING
SDL_IMAGE_MAJOR_VERSION
SDL_IMAGE_MICRO_VERSION
SDL_IMAGE_MINOR_VERSION

Functions

IMG_AddAnimationEncoderFrame
Add a frame to an animation encoder.
IMG_CloseAnimationDecoder
Close an animation decoder, finishing any decoding.
IMG_CloseAnimationEncoder
Close an animation encoder, finishing any encoding.
IMG_CreateAnimatedCursor
Create an animated cursor from an animation.
IMG_CreateAnimationDecoder
Create a decoder to read a series of images from a file.
IMG_CreateAnimationDecoderWithProperties
Create an animation decoder with the specified properties.
IMG_CreateAnimationDecoder_IO
Create a decoder to read a series of images from an IOStream.
IMG_CreateAnimationEncoder
Create an encoder to save a series of images to a file.
IMG_CreateAnimationEncoderWithProperties
Create an animation encoder with the specified properties.
IMG_CreateAnimationEncoder_IO
Create an encoder to save a series of images to an IOStream.
IMG_FreeAnimation
Dispose of an IMG_Animation and free its resources.
IMG_GetAnimationDecoderFrame
Get the next frame in an animation decoder.
IMG_GetAnimationDecoderProperties
Get the properties of an animation decoder.
IMG_GetAnimationDecoderStatus
Get the decoder status indicating the current state of the decoder.
IMG_GetClipboardImage
Get the image currently in the clipboard.
IMG_Load
Load an image from a filesystem path into a software surface.
IMG_LoadANIAnimation_IO
Load an ANI animation directly from an SDL_IOStream.
IMG_LoadAPNGAnimation_IO
Load an APNG animation directly from an SDL_IOStream.
IMG_LoadAVIFAnimation_IO
Load an AVIF animation directly from an SDL_IOStream.
IMG_LoadAVIF_IO
Load a AVIF image directly.
IMG_LoadAnimation
Load an animation from a file.
IMG_LoadAnimationTyped_IO
Load an animation from an SDL_IOStream.
IMG_LoadAnimation_IO
Load an animation from an SDL_IOStream.
IMG_LoadBMP_IO
Load a BMP image directly.
IMG_LoadCUR_IO
Load a CUR image directly.
IMG_LoadGIFAnimation_IO
Load a GIF animation directly.
IMG_LoadGIF_IO
Load a GIF image directly.
IMG_LoadGPUTexture
Load an image from a filesystem path into a GPU texture.
IMG_LoadGPUTextureTyped_IO
Load an image from an SDL data source into a GPU texture.
IMG_LoadGPUTexture_IO
Load an image from an SDL data source into a GPU texture.
IMG_LoadICO_IO
Load a ICO image directly.
IMG_LoadJPG_IO
Load a JPG image directly.
IMG_LoadJXL_IO
Load a JXL image directly.
IMG_LoadLBM_IO
Load a LBM image directly.
IMG_LoadPCX_IO
Load a PCX image directly.
IMG_LoadPNG_IO
Load a PNG image directly.
IMG_LoadPNM_IO
Load a PNM image directly.
IMG_LoadQOI_IO
Load a QOI image directly.
IMG_LoadSVG_IO
Load a SVG image directly.
IMG_LoadSizedSVG_IO
Load an SVG image, scaled to a specific size.
IMG_LoadTGA_IO
Load a TGA image directly.
IMG_LoadTIF_IO
Load a TIFF image directly.
IMG_LoadTexture
Load an image from a filesystem path into a texture.
IMG_LoadTextureTyped_IO
Load an image from an SDL data source into a texture.
IMG_LoadTexture_IO
Load an image from an SDL data source into a texture.
IMG_LoadTyped_IO
Load an image from an SDL data source into a software surface.
IMG_LoadWEBPAnimation_IO
Load a WEBP animation directly.
IMG_LoadWEBP_IO
Load a WEBP image directly.
IMG_LoadXCF_IO
Load a XCF image directly.
IMG_LoadXPM_IO
Load a XPM image directly.
IMG_LoadXV_IO
Load a XV image directly.
IMG_Load_IO
Load an image from an SDL data source into a software surface.
IMG_ReadXPMFromArray
Load an XPM image from a memory array.
IMG_ReadXPMFromArrayToRGB888
Load an XPM image from a memory array.
IMG_ResetAnimationDecoder
Reset an animation decoder.
IMG_Save
Save an SDL_Surface into an image file.
IMG_SaveANIAnimation_IO
Save an animation in ANI format to an SDL_IOStream.
IMG_SaveAPNGAnimation_IO
Save an animation in APNG format to an SDL_IOStream.
IMG_SaveAVIF
Save an SDL_Surface into a AVIF image file.
IMG_SaveAVIFAnimation_IO
Save an animation in AVIF format to an SDL_IOStream.
IMG_SaveAVIF_IO
Save an SDL_Surface into AVIF image data, via an SDL_IOStream.
IMG_SaveAnimation
Save an animation to a file.
IMG_SaveAnimationTyped_IO
Save an animation to an SDL_IOStream.
IMG_SaveBMP
Save an SDL_Surface into a BMP image file.
IMG_SaveBMP_IO
Save an SDL_Surface into BMP image data, via an SDL_IOStream.
IMG_SaveCUR
Save an SDL_Surface into a CUR image file.
IMG_SaveCUR_IO
Save an SDL_Surface into CUR image data, via an SDL_IOStream.
IMG_SaveGIF
Save an SDL_Surface into a GIF image file.
IMG_SaveGIFAnimation_IO
Save an animation in GIF format to an SDL_IOStream.
IMG_SaveGIF_IO
Save an SDL_Surface into GIF image data, via an SDL_IOStream.
IMG_SaveICO
Save an SDL_Surface into a ICO image file.
IMG_SaveICO_IO
Save an SDL_Surface into ICO image data, via an SDL_IOStream.
IMG_SaveJPG
Save an SDL_Surface into a JPEG image file.
IMG_SaveJPG_IO
Save an SDL_Surface into JPEG image data, via an SDL_IOStream.
IMG_SavePNG
Save an SDL_Surface into a PNG image file.
IMG_SavePNG_IO
Save an SDL_Surface into PNG image data, via an SDL_IOStream.
IMG_SaveTGA
Save an SDL_Surface into a TGA image file.
IMG_SaveTGA_IO
Save an SDL_Surface into TGA image data, via an SDL_IOStream.
IMG_SaveTyped_IO
Save an SDL_Surface into formatted image data, via an SDL_IOStream.
IMG_SaveWEBP
Save an SDL_Surface into a WEBP image file.
IMG_SaveWEBPAnimation_IO
Save an animation in WEBP format to an SDL_IOStream.
IMG_SaveWEBP_IO
Save an SDL_Surface into WEBP image data, via an SDL_IOStream.
IMG_Version
This function gets the version of the dynamically linked SDL_image library.
IMG_isANI
Detect ANI animated cursor data on a readable/seekable SDL_IOStream.
IMG_isAVIF
Detect AVIF image data on a readable/seekable SDL_IOStream.
IMG_isBMP
Detect BMP image data on a readable/seekable SDL_IOStream.
IMG_isCUR
Detect CUR image data on a readable/seekable SDL_IOStream.
IMG_isGIF
Detect GIF image data on a readable/seekable SDL_IOStream.
IMG_isICO
Detect ICO image data on a readable/seekable SDL_IOStream.
IMG_isJPG
Detect JPG image data on a readable/seekable SDL_IOStream.
IMG_isJXL
Detect JXL image data on a readable/seekable SDL_IOStream.
IMG_isLBM
Detect LBM image data on a readable/seekable SDL_IOStream.
IMG_isPCX
Detect PCX image data on a readable/seekable SDL_IOStream.
IMG_isPNG
Detect PNG image data on a readable/seekable SDL_IOStream.
IMG_isPNM
Detect PNM image data on a readable/seekable SDL_IOStream.
IMG_isQOI
Detect QOI image data on a readable/seekable SDL_IOStream.
IMG_isSVG
Detect SVG image data on a readable/seekable SDL_IOStream.
IMG_isTIF
Detect TIFF image data on a readable/seekable SDL_IOStream.
IMG_isWEBP
Detect WEBP image data on a readable/seekable SDL_IOStream.
IMG_isXCF
Detect XCF image data on a readable/seekable SDL_IOStream.
IMG_isXPM
Detect XPM image data on a readable/seekable SDL_IOStream.
IMG_isXV
Detect XV image data on a readable/seekable SDL_IOStream.