IMG_CreateAnimatedCursor

Function IMG_CreateAnimatedCursor 

pub unsafe extern "C" fn IMG_CreateAnimatedCursor(
    anim: *mut IMG_Animation,
    hot_x: c_int,
    hot_y: c_int,
) -> *mut SDL_Cursor
Create an animated cursor from an animation.

Parameter: anim an animation to use to create an animated cursor.

Parameter: hot_x the x position of the cursor hot spot.

Parameter: hot_y the y position of the cursor hot spot.

Returns: the new cursor on success or NULL on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL_image 3.4.0.

See Also: IMG_LoadAnimation

See Also: IMG_LoadAnimation_IO

See Also: IMG_LoadAnimationTyped_IO