IMG_CreateAnimationEncoder

Function IMG_CreateAnimationEncoder 

pub unsafe extern "C" fn IMG_CreateAnimationEncoder(
    file: *const c_char,
) -> *mut IMG_AnimationEncoder
Create an encoder to save a series of images to a file.

These animation types are currently supported:

  • ANI
  • APNG
  • AVIFS
  • GIF
  • WEBP

The file type is determined from the file extension, e.g. “file.webp” will be encoded using WEBP.

Parameter: file the file where the animation will be saved.

Returns: a new IMG_AnimationEncoder, or NULL on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL_image 3.4.0.

See Also: IMG_CreateAnimationEncoder_IO

See Also: IMG_CreateAnimationEncoderWithProperties

See Also: IMG_AddAnimationEncoderFrame

See Also: IMG_CloseAnimationEncoder