pub unsafe extern "C" fn IMG_CreateAnimationEncoderWithProperties(
props: SDL_PropertiesID,
) -> *mut IMG_AnimationEncoderExpand description
Create an animation encoder with the specified properties.
These animation types are currently supported:
- ANI
- APNG
- AVIFS
- GIF
- WEBP
These are the supported properties:
IMG_PROP_ANIMATION_ENCODER_CREATE_FILENAME_STRING: the file to save, if an SDL_IOStream isn’t being used. This is required ifIMG_PROP_ANIMATION_ENCODER_CREATE_IOSTREAM_POINTERisn’t set.IMG_PROP_ANIMATION_ENCODER_CREATE_IOSTREAM_POINTER: an SDL_IOStream that will be used to save the stream. This should not be closed until the animation encoder is closed. This is required ifIMG_PROP_ANIMATION_ENCODER_CREATE_FILENAME_STRINGisn’t set.IMG_PROP_ANIMATION_ENCODER_CREATE_IOSTREAM_AUTOCLOSE_BOOLEAN: true if closing the animation encoder should also close the associated SDL_IOStream.IMG_PROP_ANIMATION_ENCODER_CREATE_TYPE_STRING: the output file type, e.g. “webp”, defaults to the file extension ifIMG_PROP_ANIMATION_ENCODER_CREATE_FILENAME_STRINGis set.IMG_PROP_ANIMATION_ENCODER_CREATE_QUALITY_NUMBER: the compression quality, in the range of 0 to 100. The higher the number, the higher the quality and file size. This defaults to a balanced value for compression and quality.IMG_PROP_ANIMATION_ENCODER_CREATE_TIMEBASE_NUMERATOR_NUMBER: the numerator of the fraction used to multiply the pts to convert it to seconds. This defaults to 1.IMG_PROP_ANIMATION_ENCODER_CREATE_TIMEBASE_DENOMINATOR_NUMBER: the denominator of the fraction used to multiply the pts to convert it to seconds. This defaults to 1000.
Parameter: props the properties of the animation encoder.
Returns: a new IMG_AnimationEncoder, or NULL on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL_image 3.4.0.
See Also: IMG_CreateAnimationEncoder
See Also: IMG_CreateAnimationEncoder_IO
See Also: IMG_AddAnimationEncoderFrame
See Also: IMG_CloseAnimationEncoder