IMG_GetAnimationDecoderFrame

Function IMG_GetAnimationDecoderFrame 

pub unsafe extern "C" fn IMG_GetAnimationDecoderFrame(
    decoder: *mut IMG_AnimationDecoder,
    frame: *mut *mut SDL_Surface,
    duration: *mut Uint64,
) -> bool
Get the next frame in an animation decoder.

This function decodes the next frame in the animation decoder, returning it as an SDL_Surface. The returned surface should be freed with SDL_FreeSurface() when no longer needed.

If the animation decoder has no more frames or an error occurred while decoding the frame, this function returns false. In that case, please call SDL_GetError() for more information. If SDL_GetError() returns an empty string, that means there are no more available frames. If SDL_GetError() returns a valid string, that means the decoding failed.

Parameter: decoder the animation decoder.

Parameter: frame a pointer filled in with the SDL_Surface for the next frame in the animation.

Parameter: duration the duration of the frame, usually in milliseconds but can be other units if the IMG_PROP_ANIMATION_DECODER_CREATE_TIMEBASE_DENOMINATOR_NUMBER property is set when creating the decoder.

Returns: true on success or false on failure and when no more frames are available; call IMG_GetAnimationDecoderStatus() or SDL_GetError() for more information.

Available Since: This function is available since SDL_image 3.4.0.

See Also: IMG_CreateAnimationDecoder

See Also: IMG_CreateAnimationDecoder_IO

See Also: IMG_CreateAnimationDecoderWithProperties

See Also: IMG_GetAnimationDecoderStatus

See Also: IMG_ResetAnimationDecoder

See Also: IMG_CloseAnimationDecoder