IMG_GetAnimationDecoderProperties

Function IMG_GetAnimationDecoderProperties 

pub unsafe extern "C" fn IMG_GetAnimationDecoderProperties(
    decoder: *mut IMG_AnimationDecoder,
) -> SDL_PropertiesID
Get the properties of an animation decoder.

This function returns the properties of the animation decoder, which holds information about the underlying image such as description, copyright text and loop count.

Parameter: decoder the animation decoder.

Returns: the properties ID of the animation decoder, or 0 if there are no properties; call SDL_GetError() for more information.

Available Since: This function is available since SDL_image 3.4.0.

See Also: IMG_CreateAnimationDecoder

See Also: IMG_CreateAnimationDecoder_IO

See Also: IMG_CreateAnimationDecoderWithProperties