IMG_LoadAVIFAnimation_IO

Function IMG_LoadAVIFAnimation_IO 

pub unsafe extern "C" fn IMG_LoadAVIFAnimation_IO(
    src: *mut SDL_IOStream,
) -> *mut IMG_Animation
Load an AVIF animation directly from an SDL_IOStream.

If you know you definitely have an AVIF animation, you can call this function, which will skip SDL_image’s file format detection routines. Generally it’s better to use the abstract interfaces; also, there is only an SDL_IOStream interface available here.

When done with the returned animation, the app should dispose of it with a call to IMG_FreeAnimation().

Parameter: src an SDL_IOStream that data will be read from.

Returns: a new IMG_Animation, or NULL on error.

Available Since: This function is available since SDL_image 3.4.0.

See Also: IMG_isAVIF

See Also: IMG_LoadAnimation

See Also: IMG_LoadAnimation_IO

See Also: IMG_LoadAnimationTyped_IO

See Also: IMG_LoadANIAnimation_IO

See Also: IMG_LoadAPNGAnimation_IO

See Also: IMG_LoadGIFAnimation_IO

See Also: IMG_LoadWEBPAnimation_IO

See Also: IMG_FreeAnimation