IMG_LoadAnimation_IO

Function IMG_LoadAnimation_IO 

pub unsafe extern "C" fn IMG_LoadAnimation_IO(
    src: *mut SDL_IOStream,
    closeio: bool,
) -> *mut IMG_Animation
Load an animation from an SDL_IOStream.

If closeio is true, src will be closed before returning, whether this function succeeds or not. SDL_image reads everything it needs from src during this call in any case.

When done with the returned animation, the app should dispose of it with a call to IMG_FreeAnimation().

Parameter: src an SDL_IOStream that data will be read from.

Parameter: closeio true to close/free the SDL_IOStream before returning, false to leave it open.

Returns: a new IMG_Animation, or NULL on error.

Available Since: This function is available since SDL_image 3.0.0.

See Also: IMG_CreateAnimatedCursor

See Also: IMG_LoadAnimation

See Also: IMG_LoadAnimationTyped_IO

See Also: IMG_LoadANIAnimation_IO

See Also: IMG_LoadAPNGAnimation_IO

See Also: IMG_LoadAVIFAnimation_IO

See Also: IMG_LoadGIFAnimation_IO

See Also: IMG_LoadWEBPAnimation_IO

See Also: IMG_FreeAnimation