IMG_SaveAnimationTyped_IO

Function IMG_SaveAnimationTyped_IO 

pub unsafe extern "C" fn IMG_SaveAnimationTyped_IO(
    anim: *mut IMG_Animation,
    dst: *mut SDL_IOStream,
    closeio: bool,
    type_: *const c_char,
) -> bool
Save an animation to an SDL_IOStream.

If you just want to save to a filename, you can use IMG_SaveAnimation() instead.

If closeio is true, dst will be closed before returning, whether this function succeeds or not.

For formats that accept a quality, a default quality of 90 will be used.

Parameter: anim the animation to save.

Parameter: dst an SDL_IOStream that data will be written to.

Parameter: closeio true to close/free the SDL_IOStream before returning, false to leave it open.

Parameter: type a filename extension that represent this data (“GIF”, etc).

Returns: true on success or false on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL_image 3.4.0.

See Also: IMG_SaveAnimation

See Also: IMG_SaveANIAnimation_IO

See Also: IMG_SaveAPNGAnimation_IO

See Also: IMG_SaveAVIFAnimation_IO

See Also: IMG_SaveGIFAnimation_IO

See Also: IMG_SaveWEBPAnimation_IO