pub unsafe extern "C" fn IMG_SaveBMP_IO(
surface: *mut SDL_Surface,
dst: *mut SDL_IOStream,
closeio: bool,
) -> boolExpand description
Save an SDL_Surface into BMP image data, via an SDL_IOStream.
If you just want to save to a filename, you can use IMG_SaveBMP() instead.
If closeio is true, dst will be closed before returning, whether this
function succeeds or not.
Parameter: surface the SDL surface to save.
Parameter: dst the SDL_IOStream to save the image data to.
Parameter: closeio true to close/free the SDL_IOStream before returning, false to leave it open.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL_image 3.4.0.
See Also: IMG_SaveBMP