IMG_SaveICO

Function IMG_SaveICO 

pub unsafe extern "C" fn IMG_SaveICO(
    surface: *mut SDL_Surface,
    file: *const c_char,
) -> bool
Save an SDL_Surface into a ICO image file.

If the file already exists, it will be overwritten.

Parameter: surface the SDL surface to save.

Parameter: file path on the filesystem to write new file to.

Returns: true on success or false on failure; call SDL_GetError() for more information.

Available Since: This function is available since SDL_image 3.4.0.

See Also: IMG_SaveICO_IO