#[repr(transparent)]pub struct IMG_AnimationDecoderStatus(pub c_int);Expand description
An enum representing the status of an animation decoder.
Available Since: This enum is available since SDL_image 3.4.0.
Tuple Fields
0: c_intImplementations
Sourceimpl IMG_AnimationDecoderStatus
impl IMG_AnimationDecoderStatus
Sourcepub const IMG_DECODER_STATUS_INVALID: IMG_AnimationDecoderStatus
pub const IMG_DECODER_STATUS_INVALID: IMG_AnimationDecoderStatus
< The decoder is invalid
Sourcepub const IMG_DECODER_STATUS_OK: IMG_AnimationDecoderStatus
pub const IMG_DECODER_STATUS_OK: IMG_AnimationDecoderStatus
< The decoder is ready to decode the next frame
Sourcepub const IMG_DECODER_STATUS_FAILED: IMG_AnimationDecoderStatus
pub const IMG_DECODER_STATUS_FAILED: IMG_AnimationDecoderStatus
< The decoder failed to decode a frame, call SDL_GetError() for more information.
Sourcepub const IMG_DECODER_STATUS_COMPLETE: IMG_AnimationDecoderStatus
pub const IMG_DECODER_STATUS_COMPLETE: IMG_AnimationDecoderStatus
< No more frames available