pub unsafe extern "C" fn IMG_AddAnimationEncoderFrame(
encoder: *mut IMG_AnimationEncoder,
surface: *mut SDL_Surface,
duration: Uint64,
) -> boolExpand description
Add a frame to an animation encoder.
Parameter: encoder the receiving images.
Parameter: surface the surface to add as the next frame in the animation.
Parameter: duration the duration of the frame, usually in milliseconds but can
be other units if the
IMG_PROP_ANIMATION_ENCODER_CREATE_TIMEBASE_DENOMINATOR_NUMBER
property is set when creating the encoder.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL_image 3.4.0.
See Also: IMG_CreateAnimationEncoder
See Also: IMG_CreateAnimationEncoder_IO
See Also: IMG_CreateAnimationEncoderWithProperties
See Also: IMG_CloseAnimationEncoder