pub unsafe extern "C" fn IMG_CreateAnimationDecoder_IO(
src: *mut SDL_IOStream,
closeio: bool,
type_: *const c_char,
) -> *mut IMG_AnimationDecoderExpand description
Create a decoder to read a series of images from an IOStream.
These animation types are currently supported:
- ANI
- APNG
- AVIFS
- GIF
- WEBP
If closeio is true, src will be closed before returning if this
function fails, or when the animation decoder is closed if this function
succeeds.
Parameter: src an SDL_IOStream containing a series of images.
Parameter: closeio true to close the SDL_IOStream when done, false to leave it open.
Parameter: type a filename extension that represent this data (“WEBP”, etc).
Returns: a new IMG_AnimationDecoder, or NULL on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL_image 3.4.0.
See Also: IMG_CreateAnimationDecoder
See Also: IMG_CreateAnimationDecoderWithProperties
See Also: IMG_GetAnimationDecoderFrame
See Also: IMG_ResetAnimationDecoder
See Also: IMG_CloseAnimationDecoder