pub unsafe extern "C" fn IMG_LoadAnimation(
file: *const c_char,
) -> *mut IMG_AnimationExpand description
Load an animation from a file.
When done with the returned animation, the app should dispose of it with a call to IMG_FreeAnimation().
Parameter: file path on the filesystem containing an animated image.
Returns: a new IMG_Animation, or NULL on error.
Available Since: This function is available since SDL_image 3.0.0.
See Also: IMG_CreateAnimatedCursor
See Also: IMG_LoadAnimation_IO
See Also: IMG_LoadAnimationTyped_IO
See Also: IMG_LoadANIAnimation_IO
See Also: IMG_LoadAPNGAnimation_IO
See Also: IMG_LoadAVIFAnimation_IO
See Also: IMG_LoadGIFAnimation_IO
See Also: IMG_LoadWEBPAnimation_IO
See Also: IMG_FreeAnimation