pub unsafe extern "C" fn IMG_LoadGPUTexture(
device: *mut SDL_GPUDevice,
copy_pass: *mut SDL_GPUCopyPass,
file: *const c_char,
width: *mut c_int,
height: *mut c_int,
) -> *mut SDL_GPUTextureExpand description
Load an image from a filesystem path into a GPU texture.
An SDL_GPUTexture represents an image in GPU memory, usable by SDL’s GPU API. Regardless of the source format of the image, this function will create a GPU texture with the format SDL_GPU_TEXTUREFORMAT_R8G8B8A8_UNORM with no mip levels. It can be bound as a sampled texture from a graphics or compute pipeline and as a a readonly storage texture in a compute pipeline.
There is a separate function to read files from an SDL_IOStream, if you need an i/o abstraction to provide data from anywhere instead of a simple filesystem read; that function is IMG_LoadGPUTexture_IO().
When done with the returned texture, the app should dispose of it with a call to SDL_ReleaseGPUTexture().
Parameter: device the SDL_GPUDevice to use to create the GPU texture.
Parameter: copy_pass the SDL_GPUCopyPass to use to upload the loaded image to the GPU texture.
Parameter: file a path on the filesystem to load an image from.
Parameter: width a pointer filled in with the width of the GPU texture. may be NULL.
Parameter: height a pointer filled in with the width of the GPU texture. may be NULL.
Returns: a new GPU texture, or NULL on error.
Available Since: This function is available since SDL_image 3.4.0.
See Also: IMG_LoadGPUTextureTyped_IO
See Also: IMG_LoadGPUTexture_IO