pub unsafe extern "C" fn IMG_ReadXPMFromArrayToRGB888(
xpm: *mut *mut c_char,
) -> *mut SDL_SurfaceExpand description
Load an XPM image from a memory array.
The returned surface will always be a 32-bit RGB surface. If you want 8-bit indexed colors (and the XPM data allows it), use IMG_ReadXPMFromArray() instead.
When done with the returned surface, the app should dispose of it with a call to SDL_DestroySurface().
Parameter: xpm a null-terminated array of strings that comprise XPM data.
Returns: a new SDL surface, or NULL on error.
Available Since: This function is available since SDL_image 3.0.0.
See Also: IMG_ReadXPMFromArray