pub unsafe extern "C" fn IMG_ResetAnimationDecoder(
decoder: *mut IMG_AnimationDecoder,
) -> boolExpand description
Reset an animation decoder.
Calling this function resets the animation decoder, allowing it to start from the beginning again. This is useful if you want to decode the frame sequence again without creating a new decoder.
Parameter: decoder the decoder to reset.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL_image 3.4.0.
See Also: IMG_CreateAnimationDecoder
See Also: IMG_CreateAnimationDecoder_IO
See Also: IMG_CreateAnimationDecoderWithProperties
See Also: IMG_GetAnimationDecoderFrame
See Also: IMG_CloseAnimationDecoder