pub unsafe extern "C" fn IMG_SaveAnimation(
anim: *mut IMG_Animation,
file: *const c_char,
) -> boolExpand description
Save an animation to a file.
For formats that accept a quality, a default quality of 90 will be used.
Parameter: anim the animation to save.
Parameter: file path on the filesystem containing an animated image.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL_image 3.4.0.
See Also: IMG_SaveAnimationTyped_IO
See Also: IMG_SaveANIAnimation_IO
See Also: IMG_SaveAPNGAnimation_IO
See Also: IMG_SaveAVIFAnimation_IO
See Also: IMG_SaveGIFAnimation_IO
See Also: IMG_SaveWEBPAnimation_IO