pub unsafe extern "C" fn IMG_SaveBMP(
surface: *mut SDL_Surface,
file: *const c_char,
) -> boolExpand description
Save an SDL_Surface into a BMP image file.
If the file already exists, it will be overwritten.
Parameter: surface the SDL surface to save.
Parameter: file path on the filesystem to write new file to.
Returns: true on success or false on failure; call SDL_GetError() for more information.
Available Since: This function is available since SDL_image 3.4.0.
See Also: IMG_SaveBMP_IO